"""
This module exists to smooth out some of the differences between PySide, PyQt4 and PyQt5
"""

import sys

PYSIDE = 0
PYQT4 = 1
PYQT5 = 2

USE_QT_PY = None

## Automatically determine whether to use PyQt or PySide. 
## This is done by first checking to see whether one of the libraries
## is already imported. If not, then attempt to import PyQt4, then PySide.
if 'PyQt4' in sys.modules:
    USE_QT_PY = PYQT4
if 'PyQt5' in sys.modules:
    USE_QT_PY = PYQT5
elif 'PySide' in sys.modules:
    USE_QT_PY = PYSIDE
else:
    try:
        import PyQt4
        USE_QT_PY = PYQT4
    except ImportError:
        try:
            import PyQt5
            USE_QT_PY = PYQT5
        except ImportError:
            try:
                import PySide
                USE_QT_PY = PYSIDE
            except:
                pass

if USE_QT_PY == None:
    raise Exception("Requires one of PyQt4, PyQt5 or PySide; none of these packages could be imported.")

if USE_QT_PY == PYSIDE:
    from PySide.QtGui import *
    from PySide.QtCore import *
    from PySide.QtNetwork import *
    
    pyqtSignal = Signal

elif USE_QT_PY == PYQT4:
    from PyQt4.QtGui import *
    from PyQt4.QtCore import *
    from PyQt4.QtNetwork import *

elif USE_QT_PY == PYQT5:
    
    from PyQt5.QtGui import *
    from PyQt5.QtCore import *
    from PyQt5.QtNetwork import *
    from PyQt5.QtWidgets import *



#!/usr/bin/env python
# coding=utf-8
import sys
from copy import copy

from setuptools import setup, find_packages


# Defaults for py2app / cx_Freeze
default_build_options=dict(
    packages=[
        ],
    includes=[
        ],
    excludes=[
        ],
    )



setup(

    name='pyqtconfig',
    version="0.4.1",
    author='Martin Fitzpatrick',
    author_email='martin.fitzpatrick@gmail.com',
    url='https://github.com/mfitzp/pyqtconfig',
    download_url='https://github.com/mfitzp/pyqtconfig/zipball/master',
    description='An API for keeping PyQt widgets in sync with a config dictionary or QSettings object.',
    long_description='pyqtconfig is a simple API for keeping a config dict in sync with PyQt widgets. \
    Updating the widget automagically updates the dict; updating the dict updates the widget. Internal support \
    for both dictionary config, QSettings and config XML import/export. Combo and list boxes also support \
    mapping from display->internal values.',

    packages = find_packages(),
    include_package_data = True,
    package_data = {
        '': ['*.txt', '*.rst', '*.md'],
    },
    exclude_package_data = { '': ['README.txt'] },

    entry_points = {},

    install_requires = [
            ],

    keywords='bioinformatics research analysis science',
    license='GPL',
    classifiers=['Development Status :: 4 - Beta',
               'Natural Language :: English',
               'Operating System :: OS Independent',
               'Programming Language :: Python :: 2',
               'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
               'Topic :: Scientific/Engineering :: Bio-Informatics',
               'Topic :: Education',
               'Intended Audience :: Science/Research',
               'Intended Audience :: Education',
              ],

    options={},
    )
